pub struct CourtOrder {
pub text: Option<String>,
pub name: Option<String>,
pub order_type: Option<String>,
}Fields
text: Option<String>name: Option<String>order_type: Option<String>Trait Implementations
Sourceimpl Clone for CourtOrder
impl Clone for CourtOrder
Sourcefn clone(&self) -> CourtOrder
fn clone(&self) -> CourtOrder
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CourtOrder
impl Debug for CourtOrder
Sourceimpl<'de> Deserialize<'de> for CourtOrder
impl<'de> Deserialize<'de> for CourtOrder
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'a> FromSql<'a> for CourtOrder
impl<'a> FromSql<'a> for CourtOrder
Sourcefn from_sql(
_type: &Type,
buf: &'a [u8],
) -> Result<CourtOrder, Box<dyn Error + Sync + Send>>
fn from_sql( _type: &Type, buf: &'a [u8], ) -> Result<CourtOrder, Box<dyn Error + Sync + Send>>
Creates a new value of this type from a buffer of data of the specified
Postgres
Type in its binary format. Read moreSourcefn accepts(type_: &Type) -> bool
fn accepts(type_: &Type) -> bool
Determines if a value of this type can be created from the specified
Postgres
Type.Sourceimpl PartialEq for CourtOrder
impl PartialEq for CourtOrder
Sourceimpl Serialize for CourtOrder
impl Serialize for CourtOrder
Sourceimpl ToSql for CourtOrder
impl ToSql for CourtOrder
Sourcefn to_sql(
&self,
_type: &Type,
buf: &mut BytesMut,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn to_sql( &self, _type: &Type, buf: &mut BytesMut, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
Converts the value of
self into the binary format of the specified
Postgres Type, appending it to out. Read moreSourcefn accepts(type_: &Type) -> bool
fn accepts(type_: &Type) -> bool
Determines if a value of this type can be converted to the specified
Postgres
Type.Sourcefn to_sql_checked(
&self,
ty: &Type,
out: &mut BytesMut,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn to_sql_checked( &self, ty: &Type, out: &mut BytesMut, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
An adaptor method used internally by Rust-Postgres. Read more
Sourcefn encode_format(&self, _ty: &Type) -> Format
fn encode_format(&self, _ty: &Type) -> Format
Specify the encode format
impl StructuralPartialEq for CourtOrder